diff --git a/bob/devtools/scripts/ci.py b/bob/devtools/scripts/ci.py
index e00f127d8980ea546fcd3eb5e119a3e3f161292f..13cd02fa396fb9c383e3c7198aeb5d8c027594f0 100644
--- a/bob/devtools/scripts/ci.py
+++ b/bob/devtools/scripts/ci.py
@@ -280,9 +280,10 @@ def base_build(order, group, python, dry_run):
 
     # use default and add channels
     condarc_options = yaml.load(BASE_CONDARC)  #n.b.: no channels
+    channels = ['local'] + channels + ['defaults']
     logger.info('Using the following channels during build:\n  - %s',
-        '\n  - '.join(channels + ['defaults']))
-    condarc_options['channels'] = channels + ['defaults']
+        '\n  - '.join(channels))
+    condarc_options['channels'] = channels
 
   # dump packages at conda_root
   condarc_options['croot'] = os.path.join(os.environ['CONDA_ROOT'],
@@ -356,6 +357,7 @@ def test(ctx, dry_run):
       group=group,
       private=(os.environ['CI_PROJECT_VISIBILITY'] != 'public'),
       stable='CI_COMMIT_TAG' in os.environ,
+      use_local=False,
       dry_run=dry_run,
       ci=True,
       )
@@ -400,6 +402,7 @@ def build(ctx, dry_run):
       group=group,
       private=(os.environ['CI_PROJECT_VISIBILITY'] != 'public'),
       stable='CI_COMMIT_TAG' in os.environ,
+      use_local=False,
       dry_run=dry_run,
       ci=True,
       )
@@ -520,6 +523,7 @@ def nightlies(ctx, order, dry_run):
         group=group,
         private=private,
         stable=stable,
+        use_local=True,
         dry_run=dry_run,
         ci=True,
         )
diff --git a/bob/devtools/scripts/test.py b/bob/devtools/scripts/test.py
index 7a9262f2d21559a53d08464202cfb1097b93e2bf..2c389827ccbef6dff0a8f6e6ad215dc0833aa004 100644
--- a/bob/devtools/scripts/test.py
+++ b/bob/devtools/scripts/test.py
@@ -58,6 +58,9 @@ Examples:
 @click.option('-X', '--stable/--no-stable', default=False,
     help='Set this to **exclude** beta channels from your build - ' \
         'notice this option has no effect if you also pass --condarc')
+@click.option('-L', '--use-local/--no-use-local', default=False,
+    help='Set this to **include** the locally built packages on the search ' \
+        'list - notice this option has no effect if you also pass --condarc')
 @click.option('-d', '--dry-run/--no-dry-run', default=False,
     help='Only goes through the actions, but does not execute them ' \
         '(combine with the verbosity flags - e.g. ``-vvv``) to enable ' \
@@ -67,7 +70,7 @@ Examples:
 @verbosity_option()
 @bdt.raise_on_error
 def test(package, condarc, config, append_file, server, group, private, stable,
-    dry_run, ci):
+    use_local, dry_run, ci):
   """Tests (pre-built) package through conda-build with stock configuration
 
   This command wraps the execution of conda-build so that you use the same
@@ -93,10 +96,12 @@ def test(package, condarc, config, append_file, server, group, private, stable,
       condarc_options = yaml.load(f)
   else:
     # use default and add channels
+    all_channels = ['local'] if use_local else []
+    all_channels += channels + ['defaults']
     condarc_options = yaml.load(BASE_CONDARC)  #n.b.: no channels
     logger.info('Using the following channels during build:\n  - %s',
-        '\n  - '.join(channels + ['defaults']))
-    condarc_options['channels'] = channels + ['defaults']
+        '\n  - '.join(all_channels))
+    condarc_options['channels'] = all_channels
 
   conda_config = make_conda_config(config, None, append_file,
       condarc_options)
diff --git a/bob/devtools/scripts/build.py b/bob/devtools/scripts/build.py
index 581c0e3cc4e8483e96d3d97cb800d4a7a0c6e324..b716efa9b2d0e5dde9d174e48b57a3191cc39e86 100644
--- a/bob/devtools/scripts/build.py
+++ b/bob/devtools/scripts/build.py
@@ -67,6 +67,9 @@ Examples:
 @click.option('-X', '--stable/--no-stable', default=False,
     help='Set this to **exclude** beta channels from your build - ' \
         'notice this option has no effect if you also pass --condarc')
+@click.option('-L', '--use-local/--no-use-local', default=False,
+    help='Set this to **include** the locally built packages on the search ' \
+        'list - notice this option has no effect if you also pass --condarc')
 @click.option('-d', '--dry-run/--no-dry-run', default=False,
     help='Only goes through the actions, but does not execute them ' \
         '(combine with the verbosity flags - e.g. ``-vvv``) to enable ' \
@@ -76,7 +79,7 @@ Examples:
 @verbosity_option()
 @bdt.raise_on_error
 def build(recipe_dir, python, condarc, config, no_test, append_file,
     server, group, private, stable, dry_run, ci):
   """Builds package through conda-build with stock configuration
 
   This command wraps the execution of conda-build so that you use the same
@@ -104,10 +107,12 @@ def build(recipe_dir, python, condarc, config, no_test, append_file,
       condarc_options = yaml.load(f)
   else:
     # use default and add channels
+    all_channels = ['local'] if use_local else []
+    all_channels += channels + ['defaults']
     condarc_options = yaml.load(BASE_CONDARC)  #n.b.: no channels
     logger.info('Using the following channels during build:\n  - %s',
-        '\n  - '.join(channels + ['defaults']))
-    condarc_options['channels'] = channels + ['defaults']
+        '\n  - '.join(all_channels))
+    condarc_options['channels'] = all_channels
 
   # dump packages at base environment
   prefix = get_env_directory(os.environ['CONDA_EXE'], 'base')
@@ -76,7 +79,7 @@ Examples:
 @bdt.raise_on_error
 def build(recipe_dir, python, condarc, config, no_test, append_file,
-    server, group, private, stable, dry_run, ci):
+    server, group, private, stable, use_local, dry_run, ci):
   """Builds package through conda-build with stock configuration
 